@@ -2,6 +2,7 @@ mod use_async;
 mod use_before_unload;
 mod use_click_away;
 mod use_counter;
+mod use_debounce;
 mod use_default;
 mod use_drag;
 mod use_drop;
@@ -48,6 +49,7 @@ pub use use_async::*;
 pub use use_before_unload::*;
 pub use use_click_away::*;
 pub use use_counter::*;
+pub use use_debounce::*;
 pub use use_default::*;
 pub use use_drag::*;
 pub use use_drop::*;
